==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebKit2/WebProcess/InjectedBundle/InjectedBundleBackForwardList.h <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef InjectedBundleBackForwardList_h
#define InjectedBundleBackForwardList_h

#include "APIObject.h"
#include <wtf/PassRefPtr.h>

namespace WebKit {

class WebPage;

class InjectedBundleBackForwardListItem;

class InjectedBundleBackForwardList : public API::TypedObject<API::Object::Type::BundleBackForwardList> {
public:
    static PassRefPtr<InjectedBundleBackForwardList> create(WebPage* page)
    {
        return adoptRef(new InjectedBundleBackForwardList(page));
    }

    void detach() { m_page = 0; }

    void clear();

    PassRefPtr<InjectedBundleBackForwardListItem> itemAtIndex(int) const;
    int backListCount() const;
    int forwardListCount() const;

private:
    InjectedBundleBackForwardList(WebPage* page) : m_page(page) { }

    WebPage* m_page;
};

} // namespace WebKit

#endif // InjectedBundleBackForwardList_h

==> webkitgtk-2.8.4.tar.xz: webkitgtk-2.8.4/Source/WebKit2/WebProcess/InjectedBundle/InjectedBundleBackForwardList.h <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef InjectedBundleBackForwardList_h
#define InjectedBundleBackForwardList_h

#include "APIObject.h"
#include <wtf/PassRefPtr.h>

namespace WebKit {

class WebPage;

class InjectedBundleBackForwardListItem;

class InjectedBundleBackForwardList : public API::ObjectImpl<API::Object::Type::BundleBackForwardList> {
public:
    static PassRefPtr<InjectedBundleBackForwardList> create(WebPage* page)
    {
        return adoptRef(new InjectedBundleBackForwardList(page));
    }

    void detach() { m_page = 0; }

    void clear();

    PassRefPtr<InjectedBundleBackForwardListItem> itemAtIndex(int) const;
    int backListCount() const;
    int forwardListCount() const;

private:
    InjectedBundleBackForwardList(WebPage* page) : m_page(page) { }

    WebPage* m_page;
};

} // namespace WebKit

#endif // InjectedBundleBackForwardList_h
